import { Injectable } from '@angular/core';
import { Spell } from 'src/interfaces/spell';
import { Subject } from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class SpellsService {
  // Functions

  private _closeSubject = new Subject<number>();

  public closeSubject$ = this._closeSubject.asObservable();

  constructor() {}

  public closeAllOthers(level: number): void {
    this._closeSubject.next(level);
  }

  // Custom Spells

  public customSpells: Spell[] = [];

  /**
   * Returns an array of available spells for the given level and character class.
   * The results come from the official apells array and the custom spells array.
   * @param level The level of the spell.
   * @param characterClass The character class of the spell.
   * @returns An array of available spells.
   */
  public getAvailableSpells(level: number, characterClass: string): Spell[] {
    let result = this.spells
      .filter((spell) => spell.level === level)
      .filter((spell) => spell.classes.includes(characterClass));
    result.push(...this.customSpells.filter((spell) => spell.level === level));
    console.log(result);

    return result;
  }

  /**
   * Deletets a single spell from the custom spells array and the full spells array.
   * @param spellToDelete The spell to be deleted from the custom spells.
   */
  public deleteCustomSpell(spellToDelete: Spell): void {
    const customIndex = this.customSpells.findIndex(
      (spell) => spell.id === spellToDelete.id
    );
    if (customIndex > -1) {
      this.customSpells.splice(customIndex, 1);
    }
    const fullIndex = this.spells.findIndex(
      (spell) => spell.id === spellToDelete.id
    );
    if (fullIndex > -1) {
      this.spells.splice(fullIndex, 1);
    }
  }

  //

  private spells: Spell[] = [
    // Level 0
    {
      id: 0,
      isCustom: false,
      german: 'Göttliche Führung',
      english: 'guidance',
      classes: ['Test', 'Cleric', 'Druid'],
      level: 0,
      cost: 'action',
      duration: 10,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        Du berührst eine bereitwillige Kreatur. Einmal vor dem Ende des Zaubers kann das Ziel mit einem W4 würfeln und das Ergebnis zu einem Attributswurf seiner Wahl addieren. Es kann mit dem W4 vor oder nach dem Attributswurf würfeln. Dann endet der Zauber.
      `,
      description_en: `
        You touch one willing creature. Once before the spell ends, the target can roll a d4 and add the number rolled to one ability check of its choice. It can roll the die before or after making the ability check. The spell then ends.
      `,
      school: 'Divination',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1,
      isCustom: false,
      german: 'Totenläuten',
      english: 'tollTheDead',
      classes: ['Test', 'Cleric', 'Warlock', 'Wizard'],
      level: 0,
      cost: 'action',
      duration: 0,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du zeigen auf eine Kreatur, die Sie in Reichweite sehen können, und der Klang einer traurigen Glocke erfüllt für einen Moment die Luft um sie herum. Dem Ziel muss ein Weisheitswurf gelingen oder es erleidet 1W8 nekrotischen Schaden. Wenn dem Ziel einer seiner Trefferpunkte fehlt, erleidet es stattdessen 1W12 nekrotischen Schaden.

        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um einen Würfel, wenn du 5 erreichstth Stufe (2W8 oder 2W12), 11th Stufe (3W8 oder 3W12) und 17th Stufe (4W8 oder 4W12)</p>
      `,
      description_en: `
        <p>You point at one creature you can see within range, and the sound of a dolorous bell fills the air around it for a moment. The target must succeed on a Wisdom saving throw or take 1d8 necrotic damage. If the target is missing any of its hit points, it instead takes 1d12 necrotic damage.<p>

        <p> <b>At Higher Levels:</b> The spell’s damage increases by one die when you reach 5th level (2d8 or 2d12), 11th level (3d8 or 3d12), and 17th level (4d8 or 4d12).<p>
      `,
      school: 'Necromancy',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 2,
      isCustom: false,
      german: 'Thaumaturgie',
      english: 'thaumaturgy',
      classes: ['Test', 'Cleric'],
      level: 0,
      cost: 'action',
      duration: 10,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du erzeugst einen der folgenden magischen Effekte innerhalb von 9 Metern: \b\b • Deine Stimme wird dreimal lauter.\b • Du lässt einen unverschlossenen Tür oder ein Fenster aufspringen. \b• Du lässt eine Flamme aufleuchten, erlöschen oder ihre Farbe ändern. \b• Du lässt den Boden für eine Minute beben.\b • Du erzeugst Geräusche, die von dir ausgehen, wie das Flüstern einer Stimme, das Brüllen eines Löwen, das Knurren von Donner oder das Klappern von Metall. \b• Du lässt eine Tür oder ein Fenster, das du berührst, für eine Minute verriegeln oder entriegeln.',
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 3,
      german: 'Beschwörung',
      english: 'conjuration',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du schützt eine Kreatur in Reichweite vor Angriffen. Während der Wirkungsdauer muss jede Kreatur, die bei einem Angriff oder schädlichen Zauber die geschützte Kreatur als Ziel hat, zuerst einen Weisheitsrettungswurf bestehen. Scheitert der Wurf, muss die Kreatur ein neues Ziel wählen, oder sie verliert den Angriff oder Zauber. Dieser Zauber schützt die entsprechende Kreatur nicht vor Flächeneffekten wie der Explosion eines Feuerballs. Greift die geschützte Kreatur an oder wirkt sie einen Zauber auf eine feindliche Kreatur, endet der Effekt dieses Zaubers.',
      school: 'Conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 4,
      german: 'Ausbessern',
      english: 'mending',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Cleric', 'Druid', 'Wizard', 'Sorcerer'],
      timeToCast: 10,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Dieser Zauber repariert einen einzige zerbrochene nichtmagische Gegenstand, wie eine zerrissene Schnur, zwei Halbteile eines zerbrochenen Stabes, eine zerrissene Leinwand oder ein zerbrochenes Geschirr. Solange die Zerstörung nicht größer ist als 30 Zentimeter in einer beliebigen Dimension, kannst du sie reparieren. Wenn du einen magischen gegenstand reparierst, wir er physisch repariert, die Magie wird jedoch nicht wiederhergestellt.',
      school: 'Transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 5,
      german: 'Befall',
      english: 'infestation',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'poison' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du lässt eine Wolke aus Parasiten auf ein Ziel in maximal 30 Fuß Distanz localStorage. Das Ziel muss einen Konstitutionsrettungswurf bestehen, oder 1W6 Giftschaden erleiden und 5 Fuß in eine zufällige Richtung laufen. Ein W4 gibt die Richtung vor: 1: Norden, 2: Süden, 3: Westen und 4: Osten. Der Zauber löst keine Gelegenheitsangriffe aus.',
      school: 'Conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
    },
    {
      id: 6,
      german: 'Blitzköder',
      english: 'lightningLure',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Warlock'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Strength',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du wirft eine Blitzfalle auf eine Kreatur in 15 Fuß Distanz. Das Ziel muss einen Stärkerettungswurf bestehen, oder 1W8 Blitzschaden erleiden und 10 Fuß in deine Richtung gezogen werden.',
      school: 'Evocation',
      isRanged: true,
      range: 15,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
    },
    {
      id: 7,
      german: 'Botschaft',
      english: 'message',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Wizard', 'Sorcerer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du deutest mit deinem Finger auf eine Kreatur in Reichweite und flüsterst eine Botschaft. Das Ziel (und nur dieses) hört die Botschaft und kann mit einem Flüstern antworten, das nur du hörst. Du kannst diesen Zauber durch solide Gegenstände wirken, wenn du mit dem Ziel vertraut bist und weißt, dass es sich hinter der Barriere befindet. Magische Stille, 30 Zentimeter dicker Stein, 2,5 Zentimeter dickes gewöhnliches Metall, ein dünnes Bleiblech oder 90 Zentimeter dickes Holz blockieren den Zauber. Der Zauber muss keiner geraden Linie folgen und kann sich frei um Ecken oder durch Öffnungen bewegen.',
      school: 'Transmutation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 8,
      german: 'Donnerschlag',
      english: 'thunderclap',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Druid', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'thunder' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du erzeugst eine laute Donnerwoge, die alle ZTiele in 5 Fuß Entfernung trifft. Das Ziel muss einen Konstitutionsrettungswurf bestehen, oder 1W6 Donnerschaden erleiden.',
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      radius: 5,
    },
    {
      id: 9,
      german: 'Dornenpeitsche',
      english: 'thornWhip',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'piercing' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du erzeugst eine lange, dornige Peitsche aus Weinreben oder ähnlichem Material. Du musst einen Nahkrampfzauberangriff auf eine Kreatur in maximal 30 Fuß Entfernung ausführen. Bei einem Erfolg erleidet das Ziel 1W6 Piercingschaden und du ziehst das Ziel bis zu 10 Fuß in deine Richtung.',
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 10,
      german: 'Druidenkunst',
      english: 'druidcraft',
      level: 0,
      isCustom: false,

      classes: ['Test', 'Druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du flüsterst den Geistern der Natur zu und erzeugst einen der folgenden magischen Effekte in Reichweite:Du erschaffst einen winzigen, harmlosen sensorischen Effekt, der für die nächsten 24 Stunden das Wetter für deinen Aufenthaltsort vorhersagt. Der Effekt kann sich als goldene Kugel für einen wolkenlosen Himmel, als Wolke für Regen, als Schneeflocken für Schnee oder dergleichen manifestieren. Dieser Effekt hält eine Runde lang an. Du bewirkst, dass sofort eine Blume erblüht, sich eine Samenkapsel öffnet oder eine Blattknospe aufblüht. Du erzeugst einen unmittelbaren, harmlosen sensorischen Effekt, etwa fallende Blätter, einen Windhauch, die Geräusche eines kleinen Tiers oder den leichten Geruch eines Stinktiers. Der Effekt muss in einen Würfel mit 1,5 Metern Kantenlänge passen. Du entzündest oder löschst unmittelbar eine Kerze, eine Fackel oder ein kleines Lagerfeuer.',
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 11,
      german: 'Dröhnende Klinge',
      english: 'boomingBlade',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'thunder' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du füllst deine Waffe mit fröhnender Energie. Bei einem erfolgreichen nahkampfangriff erleidet das Ziel den normalen Schaden und wird bis zu Beginn deines nächsten Zuges von dröhnender Energie erfüllt. Wenn es sich bis dahin willentlich mindestens 5 Fuß bewegt, bekommt es 1W8 Donnerscahden.',
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 11,
      german: 'Einfache Illusion',
      english: 'minorIllusion',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Wizard', 'Warlock', 'Sorcerer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du erschaffst ein Geräusch oder das Abbild eines Gegenstands in Reichweite, das während der Wirkungsdauer bestehen bleibt. Der Zauber endet vorzeitig, wenn du ihn erneut wirkst oder ihn als Aktion aufhebst. Die Lautstärke des Geräuschs kann so leise wie ein Flüstern oder so laut wie ein Schrei sein. Dies kann deine Stimme oder die einer anderen Person sein, aber auch Löwengebrüll, Trommeln oder ein anderes beliebiges Geräusch. Du kannst einen durchgehenden Laut erzeugen oder während der Wirkungsdauer unterschiedliche kurze Laute. Das erschaffene Bild eines Gegenstands - etwa ein Stuhl, schlammige Fußabdrücke oder eine Truhe - darf nicht größer als ein Würfel mit 1,5 Metern Kantenlänge sein. Dieses Abbild kann weder Geräusche, Gerüche, Licht noch andere sensorische Effekte erzeugen. Physische Interaktionen mit dem Abbild enttarnen es als Illusion, da Dinge es einfach durchdringen können. Eine Kreatur, die ihre Aktion verwendet, um das Geräusch oder Abbild zu untersuchen, kann einen Wurf auf Intelligenz (Nachforschungen) gegen deinen Zauberrettungswurf-SG ausführen. Erkennt eine Kreatur die Illusion als solche, wird das Abbild oder das Geräusch weniger deutlich wahrnehmbar.',
      school: 'Illusion',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 12,
      german: 'Erde Formen',
      english: 'moldEarth',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'You choose a portion of dirt or stone that you can see within range and that fits within a 5-foot cube. You manipulate it in one of the following ways: If you target an area of loose earth, you can instantaneously excavate it, move it along the ground, and deposit it up to 5 feet away. This movement doesn’t have enough force to cause damage. You cause shapes, colors, or both to appear on the dirt or stone, spelling out words, creating images, or shaping patterns. The changes last for 1 hour. If the dirt or stone you target is on the ground, you cause it to become difficult terrain. Alternatively, you can cause the ground to become normal terrain if it is already difficult terrain. This change lasts for 1 hour. If you cast this spell multiple times, you can have no more than two of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.',
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      radius: 5,
    },
    {
      id: 13,
      german: 'Erfrierung',
      english: 'frostbite',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Warlock', 'Artificer', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'cold' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du verursachst Frostschaden an einer Kreatur in bis zu 60 Fuß Entfernung. Das Ziel muss einen Konstitutionsrettungswurf bestehen, oder 1W6 Kältenschaden erleiden. Außerdem hat er bis zum Ende deines nächsten Zuges Nachteil auf auf seinen nächsten Angriffswurf.',
      school: 'Evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 14,
      german: 'Feuerpfeil',
      english: 'fireBolt',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd10', damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du schleuderst einen Funkenwirbel auf eine Kreatur oder einen Gegenstand in Reichweite. Führe einen Fernkampf-Zauberangriff gegen das Ziel aus. Bei einem Treffer erleidet das Ziel 1W10 Feuerschaden. Der Zauber entzündet bei einem Treffer brennbare Gegenstände, die nicht getragen werden. Der Schaden dieses Zaubers wird jeweils um 1W10 erhöht, wenn du die 5. Stufe (2W10), die 11. Stufe (3W10) und die 17. Stufe (4W10) erreichst.',
      school: 'Evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 15,
      german: 'Flammen Erzeugen',
      english: 'produceFlames',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 100,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Eine flackernde Flamme erscheint in deiner Hand. Sie bleibt für die Wirkungsdauer bestehen und schadet weder dir noch deiner Ausrüstung. Die Flamme spendet in einem Radius von drei Metern helles Licht und in einem Radius von weiteren drei Metern dämmriges Licht. Der Zauber endet, wenn du ihn als Aktion beendest oder ihn erneut wirkst.Du kannst auch mit der Flamme angreifen. Dies beendet jedoch den Zauber. Wenn du diesen Zauber wirkst oder ihn als Aktion in einem späteren Zug wirkst, kannst du die Flamme auf eine Kreatur im Abstand von bis zu neun Metern von dir schleudern. Führe einen Fernkampf-Zauberangriff aus. Bei einem Treffer erleidet das Ziel 1W8 Feuerschaden. Der Schaden dieses Zaubers erhöht sich um je 1W8, wenn du die 5. Stufe (2W8), die 11. Stufe (3W8) und die 17. Stufe (4W8) erreichst',
      school: 'Conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 16,
      german: 'Flammen kontrollieren',
      english: 'controlFlames',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'You choose nonmagical flame that you can see within range and that fits within a 5-foot cube. You affect it in one of the following ways: You instantaneously expand the flame 5 feet in one direction, provided that wood or other fuel is present in the new location. You instantaneously extinguish the flames within the cube. You double or halve the area of bright light and dim light cast by the flame, change its color, or both. The change lasts for 1 hour. You cause simple shapes—such as the vague form of a creature, an inanimate object, or a location—to appear within the flames and animate as you like. The shapes last for 1 hour. If you cast this spell multiple times, you can have up to three of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.',
      school: 'Transmutation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      radius: 5,
    },
    {
      id: 17,
      german: 'Freundschaft',
      english: 'friends',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Für die Wirkungsdauer hast du einen Vorteil auf alle Charisma-Würfe, die auf eine Kreatur deiner Wahl gewirkt werden, die dir nicht feindlich gesonnen sind. Wenn der Zauber endet, begreift die Kreatur, dass du Magie verwendet hast, um ihre Stimmung zu beeinflussen und wird feindselig. Eine Kreatur, die zu Gewalt neigt, könnte dich angreifen. Andere Kreaturen könnten sich (nach Entscheidung des Spielleiters) andere Möglichkeiten suchen, um sich zu rächen, abhängig von der Art, wie du mit ihr interagiert hast.',
      school: 'Enchantment',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 18,
      german: 'Gedankensplitter',
      english: 'mindSliver',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,

      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Intelligence',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'psychic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du treibst einen verstörenden Splitter psychischer Energie in den Geist einer Kreatur, die du in Reichweite sehen kannst. Das Ziel muss einen erfolgreichen Rettungswurf auf Intelligenz durchführen, sonst nimmt es 1W6 psychischen Schaden und muss 1W4 von seinem nächsten Rettungswurf vor Ende deines nächsten Zuges abziehen. Erreichst du bestimmte Stufen, steigt der Schaden dieses Zaubers um 1W6: 5. S tufe (2W6), 11. Stufe (3W6) und 17. Stufe (4W6).',
      school: 'Enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 19,
      german: 'Gehässiger Spott',
      english: 'viciousMockery',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Wisdom',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd4', damageType: 'psychic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du rufst einer Kreatur in Richweite, die du sehen kannst, eine wahre Flut von Beleidigungen entgegen, in die subtile Verzauberungen gewebt sind. Wenn das Ziel dich hören kann (es braucht dich nicht zu verstehen), muss ihm ein Weisheitsrettungswurf gelingen, um nicht 1W4 psychischen Schaden zu erleiden und beim nächsten Angriffswurf im Nachteil zu sein, den es bis zum Einde seines nächsten Zuges ausführt. Auf höheren Graden: Der Schaden des Zaubers steigt jeweils um 1W4 bei Erreichen der 5. (2W4), 11. (3W4) und 17. Stufe (4W4).',
      school: 'Enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },

    // Level 1
    {
      id: 1000,
      german: 'Wunden verursachen',
      english: 'inflictWounds',
      level: 1,
      cost: 'action',
      isCustom: false,
      classes: ['Test', 'Cleric'],
      duration: 0,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '3', diceType: 'd10', damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Mach einen Nahkampf-Zauberangriff gegen eine Kreatur deiner Wahl. Bei einem Erfolg erleidet das Ziel 3W10 Nekrotischen Schaden. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt der Schaden für jeden Grad über dem 1. um 1W10.',
      school: 'Necromancy',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1001,
      german: 'Heilende Berührung',
      english: 'cureWounds',
      level: 1,
      cost: 'action',
      duration: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Cleric', 'Druid', 'Paladin', 'Ranger'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: '1', diceType: 'd8', additionalHeal: 4 },
      description_de:
        'Eine Kreatur, die du berührst, gewinnt Trefferpunkte in Höhe von 1W8 + deinem Attributsmodifikator im Zauberwirken zurück. Dieser Zauber wirkt nicht auf Untote oder Konstrukte. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt die Heilung für jeden Grad über dem 1. um 1W8.',
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1002,
      german: 'Magie entdecken',
      english: 'detectMagic',
      level: 1,
      cost: 'action',
      duration: 100,
      isCustom: false,
      classes: [
        'Test',
        'Bard',
        'Cleric',
        'Druid',
        'Paladin',
        'Ranger',
        'Sorcerer',
        'Wizard',
      ],
      timeToCast: 0,
      canRitual: 'true',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Während der Wirkungsdauer nimmst du die Gegenwart von Magie im Abstand von bis zu neun Metern von dir wahr. Wenn du auf diese Weise Magie wahrnimmst, kannst du deine Aktion verwenden, um schwache Auren um sichtbare magische Kreaturen oder Objekte sowie ihre magische Schule zu erkennen, falls vorhanden. Dieser Zauber durchdringt die meisten Barrieren, wird aber von 30 Zentimetern Stein, 2,5 Zentimetern gewöhnlichem Metall, dünnem Bleiblech sowie von einem Meter Holz oder Erde blockiert.',
      school: 'Divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1003,
      german: 'Segnen',
      english: 'bless',
      level: 1,
      cost: 'action',
      duration: 10,
      isCustom: false,
      classes: ['Test', 'Cleric', 'Paladin'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du segnest bis zu drei Kreaturen deiner Wahl in Reichweite. Wenn ein Ziel während der Wirkungsdauer einen Angriffs- oder Rettungswurf ausführt, darf es mit einem W4 würfeln und das Würfelergebnis zu seinem Angriffs- oder Rettungswurf addieren. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, kannst du für jeden Grad über dem 1. eine zusätzliche Kreatur als Ziel wählen.',
      school: 'Enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1004,
      german: 'Heilendes Wort',
      english: 'healingWord',
      isCustom: false,
      classes: ['Test', 'Bard', 'Cleric', 'Druid'],
      level: 1,
      cost: 'bonus action',
      duration: 0,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: '1', diceType: 'd4', additionalHeal: 4 },
      description_de:
        'Eine Kreatur deiner Wahl in Reichweite, die du sehen kannst, gewinnt Trefferpunkte in Höhe von 1W4 + deinem Zauberwirken-Attributsmodifikator zurück. Dieser Zauber wirkt nicht auf Untote oder Konstrukte. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt die Heilung für jeden Grad über dem 1. um 1W4.',
      school: 'Evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1005,
      german: 'Lenkendes Geschoss',
      english: 'guidingBolt',
      level: 1,
      cost: 'action',
      duration: 0,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '4', diceType: 'd6', damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Ein Lichtblitz schießt auf eine Kreatur deiner Wahl in Reichweite zu. Führe einen Fernkampf-Zauberangriff gegen das Ziel aus. Bei einem Erfolg erleidet das Ziel 4W6 gleißenden Schaden. Dank des mystischen dämmrigen Lichts, das auf dem Ziel glitzert, ist der nächste Angriffswurf gegen das Ziel vor Ende deines nächsten Zugs im Vorteil. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt der Schaden für jeden Grad über dem 1. um 1W6.',
      school: 'Evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1006,
      german: 'Gift und Krankheiten entdecken',
      english: 'detectPoisonAndDisease',
      level: 1,
      cost: 'action',
      duration: 100,
      isCustom: false,
      classes: ['Test', 'Cleric', 'Druid', 'Paladin', 'Ranger'],
      timeToCast: 0,
      canRitual: 'true',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Während der Wirkungsdauer nimmst du die Gegenwart und die Position von Giften, giftigen Kreaturen und Krankheiten im Abstand von bis zu neun Metern von dir wahr. Du kannst auch die Art des Gifts, der giftigen Kreatur oder der Krankheit bestimmen. Dieser Zauber durchdringt die meisten Barrieren, wird aber von 30 Zentimetern Stein, 2,5 Zentimetern gewöhnlichem Metall, dünnem Bleiblech sowie von einem Meter Holz oder Erde blockiert.',
      school: 'Divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1007,
      german: 'Heldenmut',
      english: 'heroism',
      level: 1,
      cost: 'action',
      duration: 10,
      isCustom: false,
      classes: ['Test', 'Bard', 'Paladin'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du berührst eine bereitwillige Kreatur und erfüllst sie mit Tapferkeit. Bis der Zauber endet, kann die Kreatur nicht verängstigt werden, und sie erhält zu Beginn jedes ihrer Züge temporäre Trefferpunkte in Höhe deines Zauberwirken-Attributsmodifikators. Wenn der Zauber endet, verliert das Ziel alle verbleibenden temporären Trefferpunkte dieses Zaubers. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, kannst du für jeden Grad über dem 1. eine zusätzliche Kreatur als Ziel wählen.',
      school: 'Enchantment',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1008,
      german: 'Heiligtum',
      english: 'sanctuary',
      level: 1,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du schützt eine Kreatur in Reichweite vor Angriffen. Während der Wirkungsdauer muss jede Kreatur, die bei einem Angriff oder schädlichen Zauber die geschützte Kreatur als Ziel hat, zuerst einen Weisheitsrettungswurf bestehen. Scheitert der Wurf, muss die Kreatur ein neues Ziel wählen, oder sie verliert den Angriff oder Zauber. Dieser Zauber schützt die entsprechende Kreatur nicht vor Flächeneffekten wie der Explosion eines Feuerballs. Greift die geschützte Kreatur an oder wirkt sie einen Zauber auf eine feindliche Kreatur, endet der Effekt dieses Zaubers.',
      school: 'Abjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1009,
      german: 'Illusion',
      english: 'illusion',
      level: 1,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du schützt eine Kreatur in Reichweite vor Angriffen. Während der Wirkungsdauer muss jede Kreatur, die bei einem Angriff oder schädlichen Zauber die geschützte Kreatur als Ziel hat, zuerst einen Weisheitsrettungswurf bestehen. Scheitert der Wurf, muss die Kreatur ein neues Ziel wählen, oder sie verliert den Angriff oder Zauber. Dieser Zauber schützt die entsprechende Kreatur nicht vor Flächeneffekten wie der Explosion eines Feuerballs. Greift die geschützte Kreatur an oder wirkt sie einen Zauber auf eine feindliche Kreatur, endet der Effekt dieses Zaubers.',
      school: 'Illusion',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
  ];
}
